@@ -1,5 +1,5 @@
 ﻿/*
-Copyright (c) 2003-2010, CKSource - Frederico Knabben. All rights reserved.
+Copyright (c) 2003-2011, CKSource - Frederico Knabben. All rights reserved.
 For licensing, see LICENSE.html or http://ckeditor.com/license
 */
 
@@ -31,11 +31,11 @@ CKEDITOR.lang['de'] =
 	 * Screenreader titles. Please note that screenreaders are not always capable
 	 * of reading non-English words. So be careful while translating it.
 	 */
-	editorTitle : 'Rich text editor, %1, press ALT 0 for help.', // MISSING
+	editorTitle : 'WYSIWYG-Editor, %1, drücken Sie ALT 0 für Hilfe.',
 
 	// ARIA descriptions.
-	toolbar	: 'Toolbar', // MISSING
-	editor	: 'Rich Text Editor', // MISSING
+	toolbars	: 'Editor toolbars', // MISSING
+	editor		: 'WYSIWYG-Editor',
 
 	// Toolbar buttons without dialogs.
 	source			: 'Quellcode',
@@ -56,6 +56,7 @@ CKEDITOR.lang['de'] =
 	superscript		: 'Hochgestellt',
 	horizontalrule	: 'Horizontale Linie einfügen',
 	pagebreak		: 'Seitenumbruch einfügen',
+	pagebreakAlt		: 'Seitenumbruch einfügen',
 	unlink			: 'Link entfernen',
 	undo			: 'Rückgängig',
 	redo			: 'Wiederherstellen',
@@ -66,7 +67,7 @@ CKEDITOR.lang['de'] =
 		browseServer	: 'Server durchsuchen',
 		url				: 'URL',
 		protocol		: 'Protokoll',
-		upload			: 'Upload',
+		upload			: 'Hochladen',
 		uploadSubmit	: 'Zum Server senden',
 		image			: 'Bild',
 		flash			: 'Flash',
@@ -75,7 +76,7 @@ CKEDITOR.lang['de'] =
 		radio			: 'Radiobutton',
 		textField		: 'Textfeld einzeilig',
 		textarea		: 'Textfeld mehrzeilig',
-		hiddenField		: 'verstecktes Feld',
+		hiddenField		: 'Verstecktes Feld',
 		button			: 'Klickbutton',
 		select			: 'Auswahlfeld',
 		imageButton		: 'Bildbutton',
@@ -92,43 +93,65 @@ CKEDITOR.lang['de'] =
 		cssStyle		: 'Style',
 		ok				: 'OK',
 		cancel			: 'Abbrechen',
-		close			: 'Close', // MISSING
-		preview			: 'Preview', // MISSING
+		close			: 'Schließen',
+		preview			: 'Vorschau',
 		generalTab		: 'Allgemein',
 		advancedTab		: 'Erweitert',
 		validateNumberFailed : 'Dieser Wert ist keine Nummer.',
-		confirmNewPage	: 'Alle nicht gespeicherten Änderungen gehen verlohren. Sind sie sicher die neue Seite zu laden?',
+		confirmNewPage	: 'Alle nicht gespeicherten Änderungen gehen verlohren. Sind Sie sicher die neue Seite zu laden?',
 		confirmCancel	: 'Einige Optionen wurden geändert. Wollen Sie den Dialog dennoch schließen?',
-		options			: 'Options', // MISSING
-		target			: 'Target', // MISSING
-		targetNew		: 'New Window (_blank)', // MISSING
-		targetTop		: 'Topmost Window (_top)', // MISSING
-		targetSelf		: 'Same Window (_self)', // MISSING
-		targetParent	: 'Parent Window (_parent)', // MISSING
+		options			: 'Optionen',
+		target			: 'Zielseite',
+		targetNew		: 'Neues Fenster (_blank)',
+		targetTop		: 'Oberstes Fenster (_top)',
+		targetSelf		: 'Gleiches Fenster (_self)',
+		targetParent	: 'Oberes Fenster (_parent)',
+		langDirLTR		: 'Links nach Rechts (LNR)',
+		langDirRTL		: 'Rechts nach Links (RNL)',
+		styles			: 'Style',
+		cssClasses		: 'Stylesheet Klasse',
+		width			: 'Breite',
+		height			: 'Höhe',
+		align			: 'Ausrichtung',
+		alignLeft		: 'Links',
+		alignRight		: 'Rechts',
+		alignCenter		: 'Zentriert',
+		alignTop		: 'Oben',
+		alignMiddle		: 'Mitte',
+		alignBottom		: 'Unten',
+		invalidHeight	: 'Höhe muss eine Zahl sein.',
+		invalidWidth	: 'Breite muss eine Zahl sein.',
 
 		// Put the voice-only part of the label in the span.
 		unavailable		: '%1<span class="cke_accessibility">, nicht verfügbar</span>'
 	},
 
+	contextmenu :
+	{
+		options : 'Kontextmenü Optionen'
+	},
+
 	// Special char dialog.
 	specialChar		:
 	{
 		toolbar		: 'Sonderzeichen einfügen/editieren',
-		title		: 'Sonderzeichen auswählen'
+		title		: 'Sonderzeichen auswählen',
+		options : 'Sonderzeichen Optionen'
 	},
 
 	// Link dialog.
 	link :
 	{
 		toolbar		: 'Link einfügen/editieren',
+		other 		: '<andere>',
 		menu		: 'Link editieren',
 		title		: 'Link',
 		info		: 'Link-Info',
 		target		: 'Zielseite',
-		upload		: 'Upload',
+		upload		: 'Hochladen',
 		advanced	: 'Erweitert',
 		type		: 'Link-Typ',
-		toUrl		: 'URL', // MISSING
+		toUrl		: 'URL',
 		toAnchor	: 'Anker in dieser Seite',
 		toEmail		: 'E-Mail',
 		targetFrame		: '<Frame>',
@@ -144,9 +167,7 @@ CKEDITOR.lang['de'] =
 		popupFullScreen	: 'Vollbild (IE)',
 		popupScrollBars	: 'Rollbalken',
 		popupDependent	: 'Abhängig (Netscape)',
-		popupWidth		: 'Breite',
 		popupLeft		: 'Linke Position',
-		popupHeight		: 'Höhe',
 		popupTop		: 'Obere Position',
 		id				: 'Id',
 		langDir			: 'Schreibrichtung',
@@ -154,18 +175,19 @@ CKEDITOR.lang['de'] =
 		langDirRTL		: 'Rechts nach Links (RTL)',
 		acccessKey		: 'Zugriffstaste',
 		name			: 'Name',
-		langCode		: 'Schreibrichtung',
-		tabIndex		: 'Tab-Index',
-		advisoryTitle	: 'Titel Beschreibung',
+		langCode			: 'Sprachenkürzel',
+		tabIndex			: 'Tab-Index',
+		advisoryTitle		: 'Titel Beschreibung',
 		advisoryContentType	: 'Inhaltstyp',
 		cssClasses		: 'Stylesheet Klasse',
 		charset			: 'Ziel-Zeichensatz',
 		styles			: 'Style',
-		selectAnchor	: 'Anker auswählen',
+		rel			: 'Beziehung',
+		selectAnchor		: 'Anker auswählen',
 		anchorName		: 'nach Anker Name',
-		anchorId		: 'nach Element Id',
-		emailAddress	: 'E-Mail Addresse',
-		emailSubject	: 'Betreffzeile',
+		anchorId			: 'nach Element Id',
+		emailAddress		: 'E-Mail Addresse',
+		emailSubject		: 'Betreffzeile',
 		emailBody		: 'Nachrichtentext',
 		noAnchors		: '(keine Anker im Dokument vorhanden)',
 		noUrl			: 'Bitte geben Sie die Link-URL an',
@@ -182,6 +204,30 @@ CKEDITOR.lang['de'] =
 		errorName	: 'Bitte geben Sie den Namen des Ankers ein'
 	},
 
+	// List style dialog
+	list:
+	{
+		numberedTitle		: 'Nummerierte Listen-Eigenschaften',
+		bulletedTitle		: 'Listen-Eigenschaften',
+		type				: 'Typ',
+		start				: 'Start',
+		validateStartNumber				:'List Startnummer muss eine ganze Zahl sein.',
+		circle				: 'Ring',
+		disc				: 'Kreis',
+		square				: 'Quadrat',
+		none				: 'Keine',
+		notset				: '<nicht gesetzt>',
+		armenian			: 'Armenisch Nummerierung',
+		georgian			: 'Georgisch Nummerierung (an, ban, gan, etc.)',
+		lowerRoman			: 'Klein römisch (i, ii, iii, iv, v, etc.)',
+		upperRoman			: 'Groß römisch (I, II, III, IV, V, etc.)',
+		lowerAlpha			: 'Klein alpha (a, b, c, d, e, etc.)',
+		upperAlpha			: 'Groß alpha (A, B, C, D, E, etc.)',
+		lowerGreek			: 'Klein griechisch (alpha, beta, gamma, etc.)',
+		decimal				: 'Dezimal (1, 2, 3, etc.)',
+		decimalLeadingZero	: 'Dezimal mit führende  Null (01, 02, 03, etc.)'
+	},
+
 	// Find And Replace Dialog
 	findAndReplace :
 	{
@@ -193,8 +239,8 @@ CKEDITOR.lang['de'] =
 		notFoundMsg			: 'Der gesuchte Text wurde nicht gefunden.',
 		matchCase			: 'Groß-Kleinschreibung beachten',
 		matchWord			: 'Nur ganze Worte suchen',
-		matchCyclic			: 'zyklische suche',
-		replaceAll			: 'Alle Ersetzen',
+		matchCyclic			: 'Zyklische Suche',
+		replaceAll			: 'Alle ersetzen',
 		replaceSuccessMsg	: '%1 vorkommen ersetzt.'
 	},
 
@@ -208,24 +254,18 @@ CKEDITOR.lang['de'] =
 		rows		: 'Zeile',
 		columns		: 'Spalte',
 		border		: 'Rahmen',
-		align		: 'Ausrichtung',
-		alignLeft	: 'Links',
-		alignCenter	: 'Zentriert',
-		alignRight	: 'Rechts',
-		width		: 'Breite',
 		widthPx		: 'Pixel',
 		widthPc		: '%',
-		widthUnit	: 'width unit', // MISSING
-		height		: 'Höhe',
+		widthUnit	: 'Breite Einheit',
 		cellSpace	: 'Zellenabstand außen',
 		cellPad		: 'Zellenabstand innen',
 		caption		: 'Überschrift',
 		summary		: 'Inhaltsübersicht',
-		headers		: 'Überschriften',
-		headersNone		: 'keine',
+		headers		: 'Kopfzeile',
+		headersNone		: 'Keine',
 		headersColumn	: 'Erste Spalte',
 		headersRow		: 'Erste Zeile',
-		headersBoth		: 'keine',
+		headersBoth		: 'Beide',
 		invalidRows		: 'Die Anzahl der Zeilen muß größer als 0 sein.',
 		invalidCols		: 'Die Anzahl der Spalten muß größer als 0 sein..',
 		invalidBorder	: 'Die Rahmenbreite muß eine Zahl sein.',
@@ -241,8 +281,8 @@ CKEDITOR.lang['de'] =
 			insertAfter		: 'Zelle danach einfügen',
 			deleteCell		: 'Zelle löschen',
 			merge			: 'Zellen verbinden',
-			mergeRight		: 'nach rechts verbinden',
-			mergeDown		: 'nach unten verbinden',
+			mergeRight		: 'Nach rechts verbinden',
+			mergeDown		: 'Nach unten verbinden',
 			splitHorizontal	: 'Zelle horizontal teilen',
 			splitVertical	: 'Zelle vertikal teilen',
 			title			: 'Zellen Eigenschaften',
@@ -252,9 +292,6 @@ CKEDITOR.lang['de'] =
 			wordWrap		: 'Zeilenumbruch',
 			hAlign			: 'Horizontale Ausrichtung',
 			vAlign			: 'Vertikale Ausrichtung',
-			alignTop		: 'Oben',
-			alignMiddle		: 'Mitte',
-			alignBottom		: 'Unten',
 			alignBaseline	: 'Grundlinie',
 			bgColor			: 'Hintergrundfarbe',
 			borderColor		: 'Rahmenfarbe',
@@ -266,7 +303,7 @@ CKEDITOR.lang['de'] =
 			invalidHeight	: 'Zellenhöhe muß eine Zahl sein.',
 			invalidRowSpan	: '"Anzahl Zeilen verbinden" muss eine Ganzzahl sein.',
 			invalidColSpan	: '"Anzahl Spalten verbinden" muss eine Ganzzahl sein.',
-			chooseColor		: 'Choose' // MISSING
+			chooseColor		: 'Wählen'
 		},
 
 		row :
@@ -375,27 +412,20 @@ CKEDITOR.lang['de'] =
 		btnUpload	: 'Zum Server senden',
 		upload		: 'Hochladen',
 		alt			: 'Alternativer Text',
-		width		: 'Breite',
-		height		: 'Höhe',
 		lockRatio	: 'Größenverhältnis beibehalten',
-		unlockRatio	: 'Unlock Ratio', // MISSING
+		unlockRatio	: 'Ratio freischalten',
 		resetSize	: 'Größe zurücksetzen',
 		border		: 'Rahmen',
 		hSpace		: 'Horizontal-Abstand',
 		vSpace		: 'Vertikal-Abstand',
-		align		: 'Ausrichtung',
-		alignLeft	: 'Links',
-		alignRight	: 'Rechts',
 		alertUrl	: 'Bitte geben Sie die Bild-URL an',
 		linkTab		: 'Link',
 		button2Img	: 'Möchten Sie den gewählten Bild-Button in ein einfaches Bild umwandeln?',
 		img2Button	: 'Möchten Sie das gewählten Bild in einen Bild-Button umwandeln?',
-		urlMissing	: 'Image source URL is missing.', // MISSING
-		validateWidth	: 'Width must be a whole number.', // MISSING
-		validateHeight	: 'Height must be a whole number.', // MISSING
-		validateBorder	: 'Border must be a whole number.', // MISSING
-		validateHSpace	: 'HSpace must be a whole number.', // MISSING
-		validateVSpace	: 'VSpace must be a whole number.' // MISSING
+		urlMissing	: 'Imagequelle URL fehlt.',
+		validateBorder	: 'Rahmen muß eine ganze Zahl sein.',
+		validateHSpace	: 'Horizontal-Abstand muß eine ganze Zahl sein.',
+		validateVSpace	: 'Vertikal-Abstand muß eine ganze Zahl sein.'
 	},
 
 	// Flash Dialog
@@ -404,28 +434,22 @@ CKEDITOR.lang['de'] =
 		properties		: 'Flash-Eigenschaften',
 		propertiesTab	: 'Eigenschaften',
 		title			: 'Flash-Eigenschaften',
-		chkPlay			: 'autom. Abspielen',
+		chkPlay			: 'Automatisch Abspielen',
 		chkLoop			: 'Endlosschleife',
 		chkMenu			: 'Flash-Menü aktivieren',
 		chkFull			: 'Vollbildmodus erlauben',
  		scale			: 'Skalierung',
 		scaleAll		: 'Alles anzeigen',
-		scaleNoBorder	: 'ohne Rand',
+		scaleNoBorder	: 'Ohne Rand',
 		scaleFit		: 'Passgenau',
 		access			: 'Skript Zugang',
 		accessAlways	: 'Immer',
 		accessSameDomain: 'Gleiche Domain',
 		accessNever		: 'Nie',
-		align			: 'Ausrichtung',
-		alignLeft		: 'Links',
 		alignAbsBottom	: 'Abs Unten',
 		alignAbsMiddle	: 'Abs Mitte',
 		alignBaseline	: 'Baseline',
-		alignBottom		: 'Unten',
-		alignMiddle		: 'Mitte',
-		alignRight		: 'Rechts',
 		alignTextTop	: 'Text Oben',
-		alignTop		: 'Oben',
 		quality			: 'Qualität',
 		qualityBest		: 'Beste',
 		qualityHigh		: 'Hoch',
@@ -439,13 +463,9 @@ CKEDITOR.lang['de'] =
 		windowMode		: 'Fenster Modus',
 		flashvars		: 'Variablen für Flash',
 		bgcolor			: 'Hintergrundfarbe',
-		width			: 'Breite',
-		height			: 'Höhe',
 		hSpace			: 'Horizontal-Abstand',
 		vSpace			: 'Vertikal-Abstand',
 		validateSrc		: 'Bitte geben Sie die Link-URL an',
-		validateWidth	: 'Breite muss eine Zahl sein.',
-		validateHeight	: 'Höhe muss eine Zahl sein.',
 		validateHSpace	: 'HSpace muss eine Zahl sein.',
 		validateVSpace	: 'VSpace muss eine Zahl sein.'
 	},
@@ -455,7 +475,7 @@ CKEDITOR.lang['de'] =
 	{
 		toolbar			: 'Rechtschreibprüfung',
 		title			: 'Rechtschreibprüfung',
-		notAvailable	: 'Entschuldigung, aber dieser Dienst steht im Moment nicht zur verfügung.',
+		notAvailable	: 'Entschuldigung, aber dieser Dienst steht im Moment nicht zur Verfügung.',
 		errorLoading	: 'Fehler beim laden des Dienstanbieters: %s.',
 		notInDic		: 'Nicht im Wörterbuch',
 		changeTo		: 'Ändern in',
@@ -476,12 +496,13 @@ CKEDITOR.lang['de'] =
 	smiley :
 	{
 		toolbar	: 'Smiley',
-		title	: 'Smiley auswählen'
+		title	: 'Smiley auswählen',
+		options : 'Smiley Optionen'
 	},
 
 	elementsPath :
 	{
-		eleLabel : 'Elements path', // MISSING
+		eleLabel : 'Elements Pfad',
 		eleTitle : '%1 Element'
 	},
 
@@ -507,15 +528,15 @@ CKEDITOR.lang['de'] =
 		copyError	: 'Die Sicherheitseinstellungen Ihres Browsers lassen es nicht zu, den Text automatisch kopieren. Bitte benutzen Sie die System-Zwischenablage über STRG-C (kopieren).',
 		pasteMsg	: 'Bitte fügen Sie den Text in der folgenden Box über die Tastatur (mit <STRONG>Strg+V</STRONG>) ein und bestätigen Sie mit <STRONG>OK</STRONG>.',
 		securityMsg	: 'Aufgrund von Sicherheitsbeschränkungen Ihres Browsers kann der Editor nicht direkt auf die Zwischenablage zugreifen. Bitte fügen Sie den Inhalt erneut in diesem Fenster ein.',
-		pasteArea	: 'Paste Area' // MISSING
+		pasteArea	: 'Einfügebereich'
 	},
 
 	pastefromword :
 	{
 		confirmCleanup	: 'Der Text, den Sie einfügen möchten, scheint aus MS-Word kopiert zu sein. Möchten Sie ihn zuvor bereinigen lassen?',
-		toolbar			: 'aus MS-Word einfügen',
-		title			: 'aus MS-Word einfügen',
-		error			: 'It was not possible to clean up the pasted data due to an internal error' // MISSING
+		toolbar			: 'Aus MS-Word einfügen',
+		title			: 'Aus MS-Word einfügen',
+		error			: 'Aufgrund eines internen Fehlers war es nicht möglich die eingefügten Daten zu bereinigen'
 	},
 
 	pasteText :
@@ -528,6 +549,7 @@ CKEDITOR.lang['de'] =
 	{
 		button			: 'Vorlagen',
 		title			: 'Vorlagen',
+		options : 'Vorlagen Optionen',
 		insertOption	: 'Aktuellen Inhalt ersetzen',
 		selectPromptMsg	: 'Klicken Sie auf eine Vorlage, um sie im Editor zu öffnen (der aktuelle Inhalt wird dabei gelöscht!):',
 		emptyListMsg	: '(keine Vorlagen definiert)'
@@ -538,7 +560,7 @@ CKEDITOR.lang['de'] =
 	stylesCombo :
 	{
 		label		: 'Stil',
-		panelTitle	: 'Formatting Styles', // MISSING
+		panelTitle	: 'Formatierungenstil',
 		panelTitle1	: 'Block Stilart',
 		panelTitle2	: 'Inline Stilart',
 		panelTitle3	: 'Objekt Stilart'
@@ -563,21 +585,30 @@ CKEDITOR.lang['de'] =
 
 	div :
 	{
-		title				: 'Create Div Container', // MISSING
-		toolbar				: 'Create Div Container', // MISSING
-		cssClassInputLabel	: 'Stylesheet Classes', // MISSING
-		styleSelectLabel	: 'Style', // MISSING
-		IdInputLabel		: 'Id', // MISSING
-		languageCodeInputLabel	: ' Language Code', // MISSING
-		inlineStyleInputLabel	: 'Inline Style', // MISSING
-		advisoryTitleInputLabel	: 'Advisory Title', // MISSING
-		langDirLabel		: 'Language Direction', // MISSING
-		langDirLTRLabel		: 'Left to Right (LTR)', // MISSING
-		langDirRTLLabel		: 'Right to Left (RTL)', // MISSING
-		edit				: 'Edit Div', // MISSING
-		remove				: 'Remove Div' // MISSING
+		title				: 'Div Container erzeugen',
+		toolbar				: 'Div Container erzeugen',
+		cssClassInputLabel	: 'Stylesheet Klasse',
+		styleSelectLabel	: 'Style',
+		IdInputLabel		: 'Id',
+		languageCodeInputLabel	: 'Sprachenkürzel',
+		inlineStyleInputLabel	: 'Inline Stil',
+		advisoryTitleInputLabel	: 'Tooltip',
+		langDirLabel		: 'Sprache Richtung',
+		langDirLTRLabel		: 'Links nach Rechs (LTR)',
+		langDirRTLLabel		: 'Rechs nach Links (RTL)',
+		edit				: 'Div bearbeiten',
+		remove				: 'Div entfernen'
   	},
 
+	iframe :
+	{
+		title		: 'IFrame-Eigenschaften',
+		toolbar		: 'IFrame',
+		noUrl		: 'Bitte geben Sie die IFrame-URL an',
+		scrolling	: 'Rollbalken anzeigen',
+		border		: 'Rahmen anzeigen'
+	},
+
 	font :
 	{
 		label		: 'Schriftart',
@@ -596,7 +627,7 @@ CKEDITOR.lang['de'] =
 	{
 		textColorTitle	: 'Textfarbe',
 		bgColorTitle	: 'Hintergrundfarbe',
-		panelTitle		: 'Colors', // MISSING
+		panelTitle		: 'Farben',
 		auto			: 'Automatisch',
 		more			: 'Weitere Farben...'
 	},
@@ -647,7 +678,8 @@ CKEDITOR.lang['de'] =
 
 	scayt :
 	{
-		title			: 'Rechtschreibprüfung während der Texteingabe',
+		title			: 'Rechtschreibprüfung während der Texteingabe (SCAYT)',
+		opera_title		: 'Nicht von Opera unterstützt',
 		enable			: 'SCAYT einschalten',
 		disable			: 'SCAYT ausschalten',
 		about			: 'Über SCAYT',
@@ -659,9 +691,23 @@ CKEDITOR.lang['de'] =
 		ignoreAll		: 'Alle ignorieren',
 		addWord			: 'Wort hinzufügen',
 		emptyDic		: 'Wörterbuchname sollte leer sein.',
+
 		optionsTab		: 'Optionen',
+		allCaps			: 'Groß geschriebenen Wörter ignorieren',
+		ignoreDomainNames : 'Domain-Namen ignorieren',
+		mixedCase		: 'Wörter mit gemischte Setzkasten ignorieren',
+		mixedWithDigits	: 'Wörter mit Zahlen ignorieren',
+
 		languagesTab	: 'Sprachen',
+
 		dictionariesTab	: 'Wörterbücher',
+		dic_field_name	: 'Wörterbuchname',
+		dic_create		: 'Erzeugen',
+		dic_restore		: 'Wiederherstellen',
+		dic_delete		: 'Löschen',
+		dic_rename		: 'Umbenennen',
+		dic_info		: 'Anfangs wird das Benutzerwörterbuch in einem Cookie gespeichert. Allerdings sind Cookies in der Größe begrenzt. Wenn das Benutzerwörterbuch bis zu einem Punkt wächst, wo es nicht mehr in einem Cookie gespeichert werden kann, wird das Benutzerwörterbuch auf dem Server gespeichert. Um Ihr persönliches Wörterbuch auf dem Server zu speichern, müssen Sie einen Namen für das Wörterbuch angeben. Falls  Sie schon ein gespeicherte Wörterbuch haben, geben Sie bitte dessen Namen ein und klicken Sie auf die Schaltfläche Wiederherstellen.',
+
 		aboutTab		: 'Über'
 	},
 
@@ -669,31 +715,96 @@ CKEDITOR.lang['de'] =
 	{
 		title		: 'Über CKEditor',
 		dlgTitle	: 'Über CKEditor',
-		moreInfo	: 'Für Informationen Liztenzbestimmungen besuchen sie bitte unsere Webseite:',
+		help	: 'Check $1 for help.', // MISSING
+		userGuide : 'CKEditor User\'s Guide', // MISSING
+		moreInfo	: 'Für Informationen über unsere Lizenzbestimmungen besuchen sie bitte unsere Webseite:',
 		copy		: 'Copyright &copy; $1. Alle Rechte vorbehalten.'
 	},
 
 	maximize : 'Maximieren',
-	minimize : 'Minimize', // MISSING
+	minimize : 'Minimieren',
 
 	fakeobjects :
 	{
-		anchor	: 'Anker',
-		flash	: 'Flash Animation',
-		div		: 'Seitenumbruch',
-		unknown	: 'Unbekanntes Objekt'
+		anchor		: 'Anker',
+		flash		: 'Flash Animation',
+		iframe		: 'IFrame',
+		hiddenfield	: 'Verstecktes Feld',
+		unknown		: 'Unbekanntes Objekt'
 	},
 
 	resize : 'Zum Vergrößern ziehen',
 
 	colordialog :
 	{
-		title		: 'Select color', // MISSING
-		highlight	: 'Highlight', // MISSING
-		selected	: 'Selected', // MISSING
-		clear		: 'Clear' // MISSING
+		title		: 'Farbe wählen',
+		options	:	'Farbeoptionen',
+		highlight	: 'Hervorheben',
+		selected	: 'Ausgewählte Farbe',
+		clear		: 'Entfernen'
 	},
 
-	toolbarCollapse	: 'Collapse Toolbar', // MISSING
-	toolbarExpand	: 'Expand Toolbar' // MISSING
+	toolbarCollapse	: 'Symbolleiste einklappen',
+	toolbarExpand	: 'Symbolleiste ausklappen',
+
+	toolbarGroups :
+	{
+		document : 'Document', // MISSING
+		clipboard : 'Clipboard/Undo', // MISSING
+		editing : 'Editing', // MISSING
+		forms : 'Forms', // MISSING
+		basicstyles : 'Basic Styles', // MISSING
+		paragraph : 'Paragraph', // MISSING
+		links : 'Links', // MISSING
+		insert : 'Insert', // MISSING
+		styles : 'Styles', // MISSING
+		colors : 'Colors', // MISSING
+		tools : 'Tools' // MISSING
+	},
+
+	bidi :
+	{
+		ltr : 'Leserichtung von Links nach Rechts',
+		rtl : 'Leserichtung von Rechts nach Links'
+	},
+
+	docprops :
+	{
+		label : 'Document Properties', // MISSING
+		title : 'Document Properties', // MISSING
+		design : 'Design', // MISSING
+		meta : 'Meta Tags', // MISSING
+		chooseColor : 'Choose', // MISSING
+		other : 'Other...', // MISSING
+		docTitle :	'Page Title', // MISSING
+		charset : 	'Character Set Encoding', // MISSING
+		charsetOther : 'Other Character Set Encoding', // MISSING
+		charsetASCII : 'ASCII', // MISSING
+		charsetCE : 'Central European', // MISSING
+		charsetCT : 'Chinese Traditional (Big5)', // MISSING
+		charsetCR : 'Cyrillic', // MISSING
+		charsetGR : 'Greek', // MISSING
+		charsetJP : 'Japanese', // MISSING
+		charsetKR : 'Korean', // MISSING
+		charsetTR : 'Turkish', // MISSING
+		charsetUN : 'Unicode (UTF-8)', // MISSING
+		charsetWE : 'Western European', // MISSING
+		docType : 'Document Type Heading', // MISSING
+		docTypeOther : 'Other Document Type Heading', // MISSING
+		xhtmlDec : 'Include XHTML Declarations', // MISSING
+		bgColor : 'Background Color', // MISSING
+		bgImage : 'Background Image URL', // MISSING
+		bgFixed : 'Non-scrolling (Fixed) Background', // MISSING
+		txtColor : 'Text Color', // MISSING
+		margin : 'Page Margins', // MISSING
+		marginTop : 'Top', // MISSING
+		marginLeft : 'Left', // MISSING
+		marginRight : 'Right', // MISSING
+		marginBottom : 'Bottom', // MISSING
+		metaKeywords : 'Document Indexing Keywords (comma separated)', // MISSING
+		metaDescription : 'Document Description', // MISSING
+		metaAuthor : 'Author', // MISSING
+		metaCopyright : 'Copyright', // MISSING
+		previewHtml : '<p>This is some <strong>sample text</strong>. You are using <a href="javascript:void(0)">CKEditor</a>.</p>' // MISSING
+	}
 };
