@@ -1,5 +1,5 @@
 ﻿/*
-Copyright (c) 2003-2010, CKSource - Frederico Knabben. All rights reserved.
+Copyright (c) 2003-2011, CKSource - Frederico Knabben. All rights reserved.
 For licensing, see LICENSE.html or http://ckeditor.com/license
 */
 
@@ -34,8 +34,8 @@ CKEDITOR.lang['it'] =
 	editorTitle : 'Rich text editor, %1, press ALT 0 for help.', // MISSING
 
 	// ARIA descriptions.
-	toolbar	: 'Toolbar', // MISSING
-	editor	: 'Rich Text Editor', // MISSING
+	toolbars	: 'Editor toolbars', // MISSING
+	editor		: 'Rich Text Editor', // MISSING
 
 	// Toolbar buttons without dialogs.
 	source			: 'Codice Sorgente',
@@ -56,6 +56,7 @@ CKEDITOR.lang['it'] =
 	superscript		: 'Apice',
 	horizontalrule	: 'Inserisci riga orizzontale',
 	pagebreak		: 'Inserisci interruzione di pagina',
+	pagebreakAlt		: 'Page Break', // MISSING
 	unlink			: 'Elimina collegamento',
 	undo			: 'Annulla',
 	redo			: 'Ripristina',
@@ -105,22 +106,44 @@ CKEDITOR.lang['it'] =
 		targetTop		: 'Topmost Window (_top)', // MISSING
 		targetSelf		: 'Same Window (_self)', // MISSING
 		targetParent	: 'Parent Window (_parent)', // MISSING
+		langDirLTR		: 'Left to Right (LTR)', // MISSING
+		langDirRTL		: 'Right to Left (RTL)', // MISSING
+		styles			: 'Style', // MISSING
+		cssClasses		: 'Stylesheet Classes', // MISSING
+		width			: 'Larghezza',
+		height			: 'Altezza',
+		align			: 'Allineamento',
+		alignLeft		: 'Sinistra',
+		alignRight		: 'Destra',
+		alignCenter		: 'Centrato',
+		alignTop		: 'In Alto',
+		alignMiddle		: 'Centrato',
+		alignBottom		: 'In Basso',
+		invalidHeight	: 'L\'altezza dev\'essere un numero',
+		invalidWidth	: 'La Larghezza dev\'essere un numero',
 
 		// Put the voice-only part of the label in the span.
 		unavailable		: '%1<span class="cke_accessibility">, non disponibile</span>'
 	},
 
+	contextmenu :
+	{
+		options : 'Context Menu Options' // MISSING
+	},
+
 	// Special char dialog.
 	specialChar		:
 	{
 		toolbar		: 'Inserisci carattere speciale',
-		title		: 'Seleziona carattere speciale'
+		title		: 'Seleziona carattere speciale',
+		options : 'Special Character Options' // MISSING
 	},
 
 	// Link dialog.
 	link :
 	{
 		toolbar		: 'Inserisci/Modifica collegamento',
+		other 		: '<altro>',
 		menu		: 'Modifica collegamento',
 		title		: 'Collegamento',
 		info		: 'Informazioni collegamento',
@@ -144,9 +167,7 @@ CKEDITOR.lang['it'] =
 		popupFullScreen	: 'A tutto schermo (IE)',
 		popupScrollBars	: 'Barre di scorrimento',
 		popupDependent	: 'Dipendente (Netscape)',
-		popupWidth		: 'Larghezza',
 		popupLeft		: 'Posizione da sinistra',
-		popupHeight		: 'Altezza',
 		popupTop		: 'Posizione dall\'alto',
 		id				: 'Id',
 		langDir			: 'Direzione scrittura',
@@ -154,18 +175,19 @@ CKEDITOR.lang['it'] =
 		langDirRTL		: 'Da Destra a Sinistra (RTL)',
 		acccessKey		: 'Scorciatoia<br />da tastiera',
 		name			: 'Nome',
-		langCode		: 'Direzione scrittura',
-		tabIndex		: 'Ordine di tabulazione',
-		advisoryTitle	: 'Titolo',
+		langCode			: 'Direzione scrittura',
+		tabIndex			: 'Ordine di tabulazione',
+		advisoryTitle		: 'Titolo',
 		advisoryContentType	: 'Tipo della risorsa collegata',
 		cssClasses		: 'Nome classe CSS',
 		charset			: 'Set di caretteri della risorsa collegata',
 		styles			: 'Stile',
-		selectAnchor	: 'Scegli Ancora',
+		rel			: 'Relationship', // MISSING
+		selectAnchor		: 'Scegli Ancora',
 		anchorName		: 'Per Nome',
-		anchorId		: 'Per id elemento',
-		emailAddress	: 'Indirizzo E-Mail',
-		emailSubject	: 'Oggetto del messaggio',
+		anchorId			: 'Per id elemento',
+		emailAddress		: 'Indirizzo E-Mail',
+		emailSubject		: 'Oggetto del messaggio',
 		emailBody		: 'Corpo del messaggio',
 		noAnchors		: '(Nessuna ancora disponibile nel documento)',
 		noUrl			: 'Devi inserire l\'URL del collegamento',
@@ -182,6 +204,30 @@ CKEDITOR.lang['it'] =
 		errorName	: 'Inserici il nome dell\'ancora'
 	},
 
+	// List style dialog
+	list:
+	{
+		numberedTitle		: 'Numbered List Properties', // MISSING
+		bulletedTitle		: 'Bulleted List Properties', // MISSING
+		type				: 'Type', // MISSING
+		start				: 'Start', // MISSING
+		validateStartNumber				:'List start number must be a whole number.', // MISSING
+		circle				: 'Circle', // MISSING
+		disc				: 'Disc', // MISSING
+		square				: 'Square', // MISSING
+		none				: 'None', // MISSING
+		notset				: '<not set>', // MISSING
+		armenian			: 'Armenian numbering', // MISSING
+		georgian			: 'Georgian numbering (an, ban, gan, etc.)', // MISSING
+		lowerRoman			: 'Lower Roman (i, ii, iii, iv, v, etc.)', // MISSING
+		upperRoman			: 'Upper Roman (I, II, III, IV, V, etc.)', // MISSING
+		lowerAlpha			: 'Lower Alpha (a, b, c, d, e, etc.)', // MISSING
+		upperAlpha			: 'Upper Alpha (A, B, C, D, E, etc.)', // MISSING
+		lowerGreek			: 'Lower Greek (alpha, beta, gamma, etc.)', // MISSING
+		decimal				: 'Decimal (1, 2, 3, etc.)', // MISSING
+		decimalLeadingZero	: 'Decimal leading zero (01, 02, 03, etc.)' // MISSING
+	},
+
 	// Find And Replace Dialog
 	findAndReplace :
 	{
@@ -208,15 +254,9 @@ CKEDITOR.lang['it'] =
 		rows		: 'Righe',
 		columns		: 'Colonne',
 		border		: 'Dimensione bordo',
-		align		: 'Allineamento',
-		alignLeft	: 'Sinistra',
-		alignCenter	: 'Centrato',
-		alignRight	: 'Destra',
-		width		: 'Larghezza',
 		widthPx		: 'pixel',
 		widthPc		: 'percento',
 		widthUnit	: 'width unit', // MISSING
-		height		: 'Altezza',
 		cellSpace	: 'Spaziatura celle',
 		cellPad		: 'Padding celle',
 		caption		: 'Intestazione',
@@ -252,9 +292,6 @@ CKEDITOR.lang['it'] =
 			wordWrap		: 'Ritorno a capo',
 			hAlign			: 'Allineamento orizzontale',
 			vAlign			: 'Allineamento verticale',
-			alignTop		: 'In Alto',
-			alignMiddle		: 'Al Centro',
-			alignBottom		: 'In Basso',
 			alignBaseline	: 'Linea Base',
 			bgColor			: 'Colore di Sfondo',
 			borderColor		: 'Colore del Bordo',
@@ -375,24 +412,17 @@ CKEDITOR.lang['it'] =
 		btnUpload	: 'Invia al server',
 		upload		: 'Carica',
 		alt			: 'Testo alternativo',
-		width		: 'Larghezza',
-		height		: 'Altezza',
 		lockRatio	: 'Blocca rapporto',
 		unlockRatio	: 'Unlock Ratio', // MISSING
 		resetSize	: 'Reimposta dimensione',
 		border		: 'Bordo',
 		hSpace		: 'HSpace',
 		vSpace		: 'VSpace',
-		align		: 'Allineamento',
-		alignLeft	: 'Sinistra',
-		alignRight	: 'Destra',
 		alertUrl	: 'Devi inserire l\'URL per l\'immagine',
 		linkTab		: 'Collegamento',
 		button2Img	: 'Vuoi trasformare il bottone immagine selezionato in un\'immagine semplice?',
 		img2Button	: 'Vuoi trasferomare l\'immagine selezionata in un bottone immagine?',
 		urlMissing	: 'Image source URL is missing.', // MISSING
-		validateWidth	: 'Width must be a whole number.', // MISSING
-		validateHeight	: 'Height must be a whole number.', // MISSING
 		validateBorder	: 'Border must be a whole number.', // MISSING
 		validateHSpace	: 'HSpace must be a whole number.', // MISSING
 		validateVSpace	: 'VSpace must be a whole number.' // MISSING
@@ -416,16 +446,10 @@ CKEDITOR.lang['it'] =
 		accessAlways	: 'Sempre',
 		accessSameDomain: 'Solo stesso dominio',
 		accessNever		: 'Mai',
-		align			: 'Allineamento',
-		alignLeft		: 'Sinistra',
 		alignAbsBottom	: 'In basso assoluto',
 		alignAbsMiddle	: 'Centrato assoluto',
 		alignBaseline	: 'Linea base',
-		alignBottom		: 'In Basso',
-		alignMiddle		: 'Centrato',
-		alignRight		: 'Destra',
 		alignTextTop	: 'In alto al testo',
-		alignTop		: 'In Alto',
 		quality			: 'Qualità',
 		qualityBest		: 'Massima',
 		qualityHigh		: 'Alta',
@@ -439,13 +463,9 @@ CKEDITOR.lang['it'] =
 		windowMode		: 'Modalità finestra',
 		flashvars		: 'Variabili per Flash',
 		bgcolor			: 'Colore sfondo',
-		width			: 'Larghezza',
-		height			: 'Altezza',
 		hSpace			: 'HSpace',
 		vSpace			: 'VSpace',
 		validateSrc		: 'Devi inserire l\'URL del collegamento',
-		validateWidth	: 'La Larghezza dev\'essere un numero',
-		validateHeight	: 'L\'altezza dev\'essere un numero',
 		validateHSpace	: 'L\'HSpace dev\'essere un numero.',
 		validateVSpace	: 'Il VSpace dev\'essere un numero.'
 	},
@@ -476,7 +496,8 @@ CKEDITOR.lang['it'] =
 	smiley :
 	{
 		toolbar	: 'Emoticon',
-		title	: 'Inserisci emoticon'
+		title	: 'Inserisci emoticon',
+		options : 'Smiley Options' // MISSING
 	},
 
 	elementsPath :
@@ -503,9 +524,9 @@ CKEDITOR.lang['it'] =
 	clipboard :
 	{
 		title		: 'Incolla',
-		cutError	: 'Le impostazioni di sicurezza del browser non permettono di tagliare automaticamente il testo. Usa la tastiera (Ctrl+X).',
-		copyError	: 'Le impostazioni di sicurezza del browser non permettono di copiare automaticamente il testo. Usa la tastiera (Ctrl+C).',
-		pasteMsg	: 'Incolla il testo all\'interno dell\'area sottostante usando la scorciatoia di tastiere (<STRONG>Ctrl+V</STRONG>) e premi <STRONG>OK</STRONG>.',
+		cutError	: 'Le impostazioni di sicurezza del browser non permettono di tagliare automaticamente il testo. Usa la tastiera (Ctrl/Cmd+X).',
+		copyError	: 'Le impostazioni di sicurezza del browser non permettono di copiare automaticamente il testo. Usa la tastiera (Ctrl/Cmd+C).',
+		pasteMsg	: 'Incolla il testo all\'interno dell\'area sottostante usando la scorciatoia di tastiere (<STRONG>Ctrl/Cmd+V</STRONG>) e premi <STRONG>OK</STRONG>.',
 		securityMsg	: 'A causa delle impostazioni di sicurezza del browser,l\'editor non è in grado di accedere direttamente agli appunti. E\' pertanto necessario incollarli di nuovo in questa finestra.',
 		pasteArea	: 'Paste Area' // MISSING
 	},
@@ -528,6 +549,7 @@ CKEDITOR.lang['it'] =
 	{
 		button			: 'Modelli',
 		title			: 'Contenuto dei modelli',
+		options : 'Template Options', // MISSING
 		insertOption	: 'Cancella il contenuto corrente',
 		selectPromptMsg	: 'Seleziona il modello da aprire nell\'editor<br />(il contenuto attuale verrà eliminato):',
 		emptyListMsg	: '(Nessun modello definito)'
@@ -578,6 +600,15 @@ CKEDITOR.lang['it'] =
 		remove				: 'Remove Div' // MISSING
   	},
 
+	iframe :
+	{
+		title		: 'IFrame Properties', // MISSING
+		toolbar		: 'IFrame', // MISSING
+		noUrl		: 'Please type the iframe URL', // MISSING
+		scrolling	: 'Enable scrollbars', // MISSING
+		border		: 'Show frame border' // MISSING
+	},
+
 	font :
 	{
 		label		: 'Font',
@@ -610,7 +641,7 @@ CKEDITOR.lang['it'] =
 		'008080' : 'Teal', // MISSING
 		'000080' : 'Navy', // MISSING
 		'4B0082' : 'Indigo', // MISSING
-		'696969' : 'Dim Gray', // MISSING
+		'696969' : 'Dark Gray', // MISSING
 		'B22222' : 'Fire Brick', // MISSING
 		'A52A2A' : 'Brown', // MISSING
 		'DAA520' : 'Golden Rod', // MISSING
@@ -626,7 +657,7 @@ CKEDITOR.lang['it'] =
 		'0FF' : 'Cyan', // MISSING
 		'00F' : 'Blue', // MISSING
 		'EE82EE' : 'Violet', // MISSING
-		'A9A9A9' : 'Dark Gray', // MISSING
+		'A9A9A9' : 'Dim Gray', // MISSING
 		'FFA07A' : 'Light Salmon', // MISSING
 		'FFA500' : 'Orange', // MISSING
 		'FFFF00' : 'Yellow', // MISSING
@@ -648,6 +679,7 @@ CKEDITOR.lang['it'] =
 	scayt :
 	{
 		title			: 'Controllo Ortografico Mentre Scrivi',
+		opera_title		: 'Not supported by Opera', // MISSING
 		enable			: 'Abilita COMS',
 		disable			: 'Disabilita COMS',
 		about			: 'About COMS',
@@ -659,9 +691,23 @@ CKEDITOR.lang['it'] =
 		ignoreAll		: 'Ignora tutti',
 		addWord			: 'Aggiungi Parola',
 		emptyDic		: 'Il nome del dizionario non può essere vuoto.',
+
 		optionsTab		: 'Opzioni',
+		allCaps			: 'Ignore All-Caps Words', // MISSING
+		ignoreDomainNames : 'Ignore Domain Names', // MISSING
+		mixedCase		: 'Ignore Words with Mixed Case', // MISSING
+		mixedWithDigits	: 'Ignore Words with Numbers', // MISSING
+
 		languagesTab	: 'Lingue',
+
 		dictionariesTab	: 'Dizionari',
+		dic_field_name	: 'Dictionary name', // MISSING
+		dic_create		: 'Create', // MISSING
+		dic_restore		: 'Restore', // MISSING
+		dic_delete		: 'Delete', // MISSING
+		dic_rename		: 'Rename', // MISSING
+		dic_info		: 'Initially the User Dictionary is stored in a Cookie. However, Cookies are limited in size. When the User Dictionary grows to a point where it cannot be stored in a Cookie, then the dictionary may be stored on our server. To store your personal dictionary on our server you should specify a name for your dictionary. If you already have a stored dictionary, please type its name and click the Restore button.', // MISSING
+
 		aboutTab		: 'About'
 	},
 
@@ -669,6 +715,8 @@ CKEDITOR.lang['it'] =
 	{
 		title		: 'About CKEditor',
 		dlgTitle	: 'About CKEditor',
+		help	: 'Check $1 for help.', // MISSING
+		userGuide : 'CKEditor User\'s Guide', // MISSING
 		moreInfo	: 'Per le informazioni sulla licenza si prega di visitare il nostro sito:',
 		copy		: 'Copyright &copy; $1. Tutti i diritti riservati.'
 	},
@@ -678,10 +726,11 @@ CKEDITOR.lang['it'] =
 
 	fakeobjects :
 	{
-		anchor	: 'Ancora',
-		flash	: 'Animazione Flash',
-		div		: 'Interruzione di Pagina',
-		unknown	: 'Oggetto sconosciuto'
+		anchor		: 'Ancora',
+		flash		: 'Animazione Flash',
+		iframe		: 'IFrame', // MISSING
+		hiddenfield	: 'Hidden Field', // MISSING
+		unknown		: 'Oggetto sconosciuto'
 	},
 
 	resize : 'Trascina per ridimensionare',
@@ -689,11 +738,73 @@ CKEDITOR.lang['it'] =
 	colordialog :
 	{
 		title		: 'Select color', // MISSING
+		options	:	'Color Options', // MISSING
 		highlight	: 'Highlight', // MISSING
-		selected	: 'Selected', // MISSING
+		selected	: 'Selected Color', // MISSING
 		clear		: 'Clear' // MISSING
 	},
 
 	toolbarCollapse	: 'Collapse Toolbar', // MISSING
-	toolbarExpand	: 'Expand Toolbar' // MISSING
+	toolbarExpand	: 'Expand Toolbar', // MISSING
+
+	toolbarGroups :
+	{
+		document : 'Document', // MISSING
+		clipboard : 'Clipboard/Undo', // MISSING
+		editing : 'Editing', // MISSING
+		forms : 'Forms', // MISSING
+		basicstyles : 'Basic Styles', // MISSING
+		paragraph : 'Paragraph', // MISSING
+		links : 'Links', // MISSING
+		insert : 'Insert', // MISSING
+		styles : 'Styles', // MISSING
+		colors : 'Colors', // MISSING
+		tools : 'Tools' // MISSING
+	},
+
+	bidi :
+	{
+		ltr : 'Text direction from left to right', // MISSING
+		rtl : 'Text direction from right to left' // MISSING
+	},
+
+	docprops :
+	{
+		label : 'Document Properties', // MISSING
+		title : 'Document Properties', // MISSING
+		design : 'Design', // MISSING
+		meta : 'Meta Tags', // MISSING
+		chooseColor : 'Choose', // MISSING
+		other : 'Other...', // MISSING
+		docTitle :	'Page Title', // MISSING
+		charset : 	'Character Set Encoding', // MISSING
+		charsetOther : 'Other Character Set Encoding', // MISSING
+		charsetASCII : 'ASCII', // MISSING
+		charsetCE : 'Central European', // MISSING
+		charsetCT : 'Chinese Traditional (Big5)', // MISSING
+		charsetCR : 'Cyrillic', // MISSING
+		charsetGR : 'Greek', // MISSING
+		charsetJP : 'Japanese', // MISSING
+		charsetKR : 'Korean', // MISSING
+		charsetTR : 'Turkish', // MISSING
+		charsetUN : 'Unicode (UTF-8)', // MISSING
+		charsetWE : 'Western European', // MISSING
+		docType : 'Document Type Heading', // MISSING
+		docTypeOther : 'Other Document Type Heading', // MISSING
+		xhtmlDec : 'Include XHTML Declarations', // MISSING
+		bgColor : 'Background Color', // MISSING
+		bgImage : 'Background Image URL', // MISSING
+		bgFixed : 'Non-scrolling (Fixed) Background', // MISSING
+		txtColor : 'Text Color', // MISSING
+		margin : 'Page Margins', // MISSING
+		marginTop : 'Top', // MISSING
+		marginLeft : 'Left', // MISSING
+		marginRight : 'Right', // MISSING
+		marginBottom : 'Bottom', // MISSING
+		metaKeywords : 'Document Indexing Keywords (comma separated)', // MISSING
+		metaDescription : 'Document Description', // MISSING
+		metaAuthor : 'Author', // MISSING
+		metaCopyright : 'Copyright', // MISSING
+		previewHtml : '<p>This is some <strong>sample text</strong>. You are using <a href="javascript:void(0)">CKEditor</a>.</p>' // MISSING
+	}
 };
