@@ -1,5 +1,5 @@
 ﻿/*
-Copyright (c) 2003-2010, CKSource - Frederico Knabben. All rights reserved.
+Copyright (c) 2003-2011, CKSource - Frederico Knabben. All rights reserved.
 For licensing, see LICENSE.html or http://ckeditor.com/license
 */
 
@@ -31,31 +31,32 @@ CKEDITOR.lang['no'] =
 	 * Screenreader titles. Please note that screenreaders are not always capable
 	 * of reading non-English words. So be careful while translating it.
 	 */
-	editorTitle : 'Rich text editor, %1, press ALT 0 for help.', // MISSING
+	editorTitle : 'Rikteksteditor, %1, trykk ALT 0 for hjelp.',
 
 	// ARIA descriptions.
-	toolbar	: 'Toolbar', // MISSING
-	editor	: 'Rich Text Editor', // MISSING
+	toolbars	: 'Editor toolbars', // MISSING
+	editor		: 'Rikteksteditor',
 
 	// Toolbar buttons without dialogs.
 	source			: 'Kilde',
-	newPage			: 'Ny Side',
+	newPage			: 'Ny side',
 	save			: 'Lagre',
 	preview			: 'Forhåndsvis',
 	cut				: 'Klipp ut',
 	copy			: 'Kopier',
 	paste			: 'Lim inn',
 	print			: 'Skriv ut',
-	underline		: 'Understrek',
+	underline		: 'Understreking',
 	bold			: 'Fet',
 	italic			: 'Kursiv',
 	selectAll		: 'Merk alt',
-	removeFormat	: 'Fjern format',
-	strike			: 'Gjennomstrek',
+	removeFormat	: 'Fjern formatering',
+	strike			: 'Gjennomstreking',
 	subscript		: 'Senket skrift',
 	superscript		: 'Hevet skrift',
 	horizontalrule	: 'Sett inn horisontal linje',
-	pagebreak		: 'Sett inn sideskift',
+	pagebreak		: 'Sett inn sideskift for utskrift',
+	pagebreakAlt		: 'Sideskift',
 	unlink			: 'Fjern lenke',
 	undo			: 'Angre',
 	redo			: 'Gjør om',
@@ -92,35 +93,57 @@ CKEDITOR.lang['no'] =
 		cssStyle		: 'Stil',
 		ok				: 'OK',
 		cancel			: 'Avbryt',
-		close			: 'Close', // MISSING
-		preview			: 'Preview', // MISSING
+		close			: 'Lukk',
+		preview			: 'Forhåndsvis',
 		generalTab		: 'Generelt',
 		advancedTab		: 'Avansert',
-		validateNumberFailed : 'Denne verdien er ikke ett nummer',
-		confirmNewPage	: 'Alle endringer som er gjort i dette innholdet vil bli tapt. Er du sikker på at du vil laste en ny side?',
+		validateNumberFailed : 'Denne verdien er ikke et tall.',
+		confirmNewPage	: 'Alle ulagrede endringer som er gjort i dette innholdet vil bli tapt. Er du sikker på at du vil laste en ny side?',
 		confirmCancel	: 'Noen av valgene har blitt endret. Er du sikker på at du vil lukke dialogen?',
-		options			: 'Options', // MISSING
-		target			: 'Target', // MISSING
-		targetNew		: 'New Window (_blank)', // MISSING
-		targetTop		: 'Topmost Window (_top)', // MISSING
-		targetSelf		: 'Same Window (_self)', // MISSING
-		targetParent	: 'Parent Window (_parent)', // MISSING
+		options			: 'Valg',
+		target			: 'Mål',
+		targetNew		: 'Nytt vindu (_blank)',
+		targetTop		: 'Hele vindu (_top)',
+		targetSelf		: 'Samme vindu (_self)',
+		targetParent	: 'Foreldrevindu (_parent)',
+		langDirLTR		: 'Venstre til høyre (VTH)',
+		langDirRTL		: 'Høyre til venstre (HTV)',
+		styles			: 'Stil',
+		cssClasses		: 'Stilarkklasser',
+		width			: 'Bredde',
+		height			: 'Høyde',
+		align			: 'Juster',
+		alignLeft		: 'Venstre',
+		alignRight		: 'Høyre',
+		alignCenter		: 'Midtjuster',
+		alignTop		: 'Topp',
+		alignMiddle		: 'Midten',
+		alignBottom		: 'Bunn',
+		invalidHeight	: 'Høyde må være et tall.',
+		invalidWidth	: 'Bredde må være et tall.',
 
 		// Put the voice-only part of the label in the span.
 		unavailable		: '%1<span class="cke_accessibility">, utilgjenglig</span>'
 	},
 
+	contextmenu :
+	{
+		options : 'Alternativer for høyreklikkmeny'
+	},
+
 	// Special char dialog.
 	specialChar		:
 	{
-		toolbar		: 'Sett inn spesielt tegn',
-		title		: 'Velg spesielt tegn'
+		toolbar		: 'Sett inn spesialtegn',
+		title		: 'Velg spesialtegn',
+		options : 'Alternativer for spesialtegn'
 	},
 
 	// Link dialog.
 	link :
 	{
 		toolbar		: 'Sett inn/Rediger lenke',
+		other 		: '<annen>',
 		menu		: 'Rediger lenke',
 		title		: 'Lenke',
 		info		: 'Lenkeinfo',
@@ -128,25 +151,23 @@ CKEDITOR.lang['no'] =
 		upload		: 'Last opp',
 		advanced	: 'Avansert',
 		type		: 'Lenketype',
-		toUrl		: 'URL', // MISSING
+		toUrl		: 'URL',
 		toAnchor	: 'Lenke til anker i teksten',
 		toEmail		: 'E-post',
 		targetFrame		: '<ramme>',
-		targetPopup		: '<popup vindu>',
+		targetPopup		: '<popup-vindu>',
 		targetFrameName	: 'Målramme',
-		targetPopupName	: 'Navn på popup-vindus',
+		targetPopupName	: 'Navn på popup-vindu',
 		popupFeatures	: 'Egenskaper for popup-vindu',
-		popupResizable	: 'Skalérbar',
+		popupResizable	: 'Skalerbar',
 		popupStatusBar	: 'Statuslinje',
 		popupLocationBar: 'Adresselinje',
 		popupToolbar	: 'Verktøylinje',
 		popupMenuBar	: 'Menylinje',
-		popupFullScreen	: 'Full skjerm (IE)',
+		popupFullScreen	: 'Fullskjerm (IE)',
 		popupScrollBars	: 'Scrollbar',
 		popupDependent	: 'Avhenging (Netscape)',
-		popupWidth		: 'Bredde',
 		popupLeft		: 'Venstre posisjon',
-		popupHeight		: 'Høyde',
 		popupTop		: 'Topp-posisjon',
 		id				: 'Id',
 		langDir			: 'Språkretning',
@@ -154,21 +175,22 @@ CKEDITOR.lang['no'] =
 		langDirRTL		: 'Høyre til venstre (HTV)',
 		acccessKey		: 'Aksessknapp',
 		name			: 'Navn',
-		langCode		: 'Språkretning',
-		tabIndex		: 'Tab Indeks',
-		advisoryTitle	: 'Tittel',
+		langCode			: 'Språkkode',
+		tabIndex			: 'Tabindeks',
+		advisoryTitle		: 'Tittel',
 		advisoryContentType	: 'Type',
 		cssClasses		: 'Stilarkklasser',
-		charset			: 'Lenket språkkart',
+		charset			: 'Lenket tegnsett',
 		styles			: 'Stil',
-		selectAnchor	: 'Velg et anker',
+		rel			: 'Relationship', // MISSING
+		selectAnchor		: 'Velg et anker',
 		anchorName		: 'Anker etter navn',
-		anchorId		: 'Element etter ID',
-		emailAddress	: 'E-postadresse',
-		emailSubject	: 'Meldingsemne',
+		anchorId			: 'Element etter ID',
+		emailAddress		: 'E-postadresse',
+		emailSubject		: 'Meldingsemne',
 		emailBody		: 'Melding',
 		noAnchors		: '(Ingen anker i dokumentet)',
-		noUrl			: 'Vennligst skriv inn lenkens url',
+		noUrl			: 'Vennligst skriv inn lenkens URL',
 		noEmail			: 'Vennligst skriv inn e-postadressen'
 	},
 
@@ -182,6 +204,30 @@ CKEDITOR.lang['no'] =
 		errorName	: 'Vennligst skriv inn ankernavnet'
 	},
 
+	// List style dialog
+	list:
+	{
+		numberedTitle		: 'Egenskaper for nummerert liste',
+		bulletedTitle		: 'Egenskaper for punktmerket liste',
+		type				: 'Type',
+		start				: 'Start',
+		validateStartNumber				:'Starten på listen må være et heltall.',
+		circle				: 'Sirkel',
+		disc				: 'Disk',
+		square				: 'Firkant',
+		none				: 'Ingen',
+		notset				: '<ikke satt>',
+		armenian			: 'Armensk nummerering',
+		georgian			: 'Georgisk nummerering (an, ban, gan, osv.)',
+		lowerRoman			: 'Romertall, små (i, ii, iii, iv, v, osv.)',
+		upperRoman			: 'Romertall, store (I, II, III, IV, V, osv.)',
+		lowerAlpha			: 'Alfabetisk, små (a, b, c, d, e, osv.)',
+		upperAlpha			: 'Alfabetisk, store (A, B, C, D, E, osv.)',
+		lowerGreek			: 'Gresk, små (alpha, beta, gamma, osv.)',
+		decimal				: 'Tall (1, 2, 3, osv.)',
+		decimalLeadingZero	: 'Tall, med førstesiffer null (01, 02, 03, osv.)'
+	},
+
 	// Find And Replace Dialog
 	findAndReplace :
 	{
@@ -195,7 +241,7 @@ CKEDITOR.lang['no'] =
 		matchWord			: 'Bare hele ord',
 		matchCyclic			: 'Søk i hele dokumentet',
 		replaceAll			: 'Erstatt alle',
-		replaceSuccessMsg	: '%1 tilfelle erstattet.'
+		replaceSuccessMsg	: '%1 tilfelle(r) erstattet.'
 	},
 
 	// Table Dialog
@@ -208,15 +254,9 @@ CKEDITOR.lang['no'] =
 		rows		: 'Rader',
 		columns		: 'Kolonner',
 		border		: 'Rammestørrelse',
-		align		: 'Justering',
-		alignLeft	: 'Venstre',
-		alignCenter	: 'Midtjuster',
-		alignRight	: 'Høyre',
-		width		: 'Bredde',
 		widthPx		: 'piksler',
 		widthPc		: 'prosent',
-		widthUnit	: 'width unit', // MISSING
-		height		: 'Høyde',
+		widthUnit	: 'Bredde-enhet',
 		cellSpace	: 'Cellemarg',
 		cellPad		: 'Cellepolstring',
 		caption		: 'Tittel',
@@ -226,13 +266,13 @@ CKEDITOR.lang['no'] =
 		headersColumn	: 'Første kolonne',
 		headersRow		: 'Første rad',
 		headersBoth		: 'Begge',
-		invalidRows		: 'Antall rader må være ett tall større enn 0.',
-		invalidCols		: 'Antall kolonner må være ett tall større enn 0.',
-		invalidBorder	: 'Rammestørrelse må være ett tall.',
-		invalidWidth	: 'Tabellbredde må være ett nummer.',
-		invalidHeight	: 'Tabellhøyde må være ett nummer.',
-		invalidCellSpacing	: 'Cellemellomrom må være ett nummer.',
-		invalidCellPadding	: 'Cellefyll må være ett nummer.',
+		invalidRows		: 'Antall rader må være et tall større enn 0.',
+		invalidCols		: 'Antall kolonner må være et tall større enn 0.',
+		invalidBorder	: 'Rammestørrelse må være et tall.',
+		invalidWidth	: 'Tabellbredde må være et tall.',
+		invalidHeight	: 'Tabellhøyde må være et tall.',
+		invalidCellSpacing	: 'Cellemarg må være et tall.',
+		invalidCellPadding	: 'Cellepolstring må være et tall.',
 
 		cell :
 		{
@@ -252,9 +292,6 @@ CKEDITOR.lang['no'] =
 			wordWrap		: 'Tekstbrytning',
 			hAlign			: 'Horisontal justering',
 			vAlign			: 'Vertikal justering',
-			alignTop		: 'Topp',
-			alignMiddle		: 'Midten',
-			alignBottom		: 'Bunnen',
 			alignBaseline	: 'Grunnlinje',
 			bgColor			: 'Bakgrunnsfarge',
 			borderColor		: 'Rammefarge',
@@ -262,10 +299,10 @@ CKEDITOR.lang['no'] =
 			header			: 'Overskrift',
 			yes				: 'Ja',
 			no				: 'Nei',
-			invalidWidth	: 'Cellebredde må være ett nummer',
-			invalidHeight	: 'Cellehøyde må være ett nummer',
-			invalidRowSpan	: 'Radspenn må være ett nummer.',
-			invalidColSpan	: 'Kolonnespenn må være ett nummer.',
+			invalidWidth	: 'Cellebredde må være et tall.',
+			invalidHeight	: 'Cellehøyde må være et tall.',
+			invalidRowSpan	: 'Radspenn må være et heltall.',
+			invalidColSpan	: 'Kolonnespenn må være et heltall.',
 			chooseColor		: 'Velg'
 		},
 
@@ -375,27 +412,20 @@ CKEDITOR.lang['no'] =
 		btnUpload	: 'Send det til serveren',
 		upload		: 'Last opp',
 		alt			: 'Alternativ tekst',
-		width		: 'Bredde',
-		height		: 'Høyde',
 		lockRatio	: 'Lås forhold',
-		unlockRatio	: 'Unlock Ratio', // MISSING
+		unlockRatio	: 'Ikke lås forhold',
 		resetSize	: 'Tilbakestill størrelse',
 		border		: 'Ramme',
 		hSpace		: 'HMarg',
 		vSpace		: 'VMarg',
-		align		: 'Juster',
-		alignLeft	: 'Venstre',
-		alignRight	: 'Høyre',
 		alertUrl	: 'Vennligst skriv bilde-urlen',
 		linkTab		: 'Lenke',
-		button2Img	: 'Vil du endre den valgte bildeknappen til ett vanlig bilde?',
+		button2Img	: 'Vil du endre den valgte bildeknappen til et vanlig bilde?',
 		img2Button	: 'Vil du endre det valgte bildet til en bildeknapp?',
 		urlMissing	: 'Bildets adresse mangler.',
-		validateWidth	: 'Width must be a whole number.', // MISSING
-		validateHeight	: 'Height must be a whole number.', // MISSING
-		validateBorder	: 'Border must be a whole number.', // MISSING
-		validateHSpace	: 'HSpace must be a whole number.', // MISSING
-		validateVSpace	: 'VSpace must be a whole number.' // MISSING
+		validateBorder	: 'Ramme må være et heltall.',
+		validateHSpace	: 'HMarg må være et heltall.',
+		validateVSpace	: 'VMarg må være et heltall.'
 	},
 
 	// Flash Dialog
@@ -416,38 +446,28 @@ CKEDITOR.lang['no'] =
 		accessAlways	: 'Alltid',
 		accessSameDomain: 'Samme domene',
 		accessNever		: 'Aldri',
-		align			: 'Juster',
-		alignLeft		: 'Venstre',
 		alignAbsBottom	: 'Abs bunn',
 		alignAbsMiddle	: 'Abs midten',
 		alignBaseline	: 'Bunnlinje',
-		alignBottom		: 'Bunn',
-		alignMiddle		: 'Midten',
-		alignRight		: 'Høyre',
 		alignTextTop	: 'Tekst topp',
-		alignTop		: 'Topp',
 		quality			: 'Kvalitet',
 		qualityBest		: 'Best',
 		qualityHigh		: 'Høy',
-		qualityAutoHigh	: 'Auto Høy',
+		qualityAutoHigh	: 'Auto høy',
 		qualityMedium	: 'Medium',
-		qualityAutoLow	: 'Auto Lav',
+		qualityAutoLow	: 'Auto lav',
 		qualityLow		: 'Lav',
 		windowModeWindow: 'Vindu',
 		windowModeOpaque: 'Opaque',
 		windowModeTransparent : 'Gjennomsiktig',
-		windowMode		: 'Vindu modus',
+		windowMode		: 'Vindumodus',
 		flashvars		: 'Variabler for flash',
 		bgcolor			: 'Bakgrunnsfarge',
-		width			: 'Bredde',
-		height			: 'Høyde',
 		hSpace			: 'HMarg',
 		vSpace			: 'VMarg',
-		validateSrc		: 'Vennligst skriv inn lenkens url',
-		validateWidth	: 'Bredde må være ett nummer.',
-		validateHeight	: 'Høyde må være ett nummer',
-		validateHSpace	: 'HSpace må være ett nummer.',
-		validateVSpace	: 'VSpace må være ett nummer.'
+		validateSrc		: 'Vennligst skriv inn lenkens url.',
+		validateHSpace	: 'HMarg må være et tall.',
+		validateVSpace	: 'VMarg må være et tall.'
 	},
 
 	// Speller Pages Dialog
@@ -456,7 +476,7 @@ CKEDITOR.lang['no'] =
 		toolbar			: 'Stavekontroll',
 		title			: 'Stavekontroll',
 		notAvailable	: 'Beklager, tjenesten er utilgjenglig nå.',
-		errorLoading	: 'Feil under lasting av applicationstjeneste tjener: %s.',
+		errorLoading	: 'Feil under lasting av applikasjonstjenestetjener: %s.',
 		notInDic		: 'Ikke i ordboken',
 		changeTo		: 'Endre til',
 		btnIgnore		: 'Ignorer',
@@ -476,46 +496,47 @@ CKEDITOR.lang['no'] =
 	smiley :
 	{
 		toolbar	: 'Smil',
-		title	: 'Sett inn smil'
+		title	: 'Sett inn smil',
+		options : 'Alternativer for smil'
 	},
 
 	elementsPath :
 	{
-		eleLabel : 'Elements path', // MISSING
+		eleLabel : 'Element-sti',
 		eleTitle : '%1 element'
 	},
 
-	numberedlist	: 'Nummerert liste',
-	bulletedlist	: 'Uordnet liste',
-	indent			: 'Øk nivå',
-	outdent			: 'Senk nivå',
+	numberedlist	: 'Legg til/Fjern nummerert liste',
+	bulletedlist	: 'Legg til/Fjern punktmerket liste',
+	indent			: 'Øk innrykk',
+	outdent			: 'Reduser innrykk',
 
 	justify :
 	{
 		left	: 'Venstrejuster',
-		center	: 'Midtjuster',
+		center	: 'Midtstill',
 		right	: 'Høyrejuster',
 		block	: 'Blokkjuster'
 	},
 
-	blockquote : 'Blockquote',
+	blockquote : 'Sitatblokk',
 
 	clipboard :
 	{
 		title		: 'Lim inn',
-		cutError	: 'Din nettlesers sikkerhetsinstillinger tillater ikke automatisk klipping av tekst. Vennligst bruk snareveien (Ctrl+X).',
-		copyError	: 'Din nettlesers sikkerhetsinstillinger tillater ikke automatisk kopiering av tekst. Vennligst bruk snareveien (Ctrl+C).',
-		pasteMsg	: 'Vennligst lim inn i den følgende boksen med tastaturet (<STRONG>Ctrl+V</STRONG>) og trykk <STRONG>OK</STRONG>.',
-		securityMsg	: 'Din nettlesers sikkerhetsinstillinger gir ikke redigeringsverktøyet direkte tilgang til utklippstavlen. Du må lime det igjen i dette vinduet.',
-		pasteArea	: 'Paste Area' // MISSING
+		cutError	: 'Din nettlesers sikkerhetsinstillinger tillater ikke automatisk klipping av tekst. Vennligst bruk snareveien (Ctrl/Cmd+X).',
+		copyError	: 'Din nettlesers sikkerhetsinstillinger tillater ikke automatisk kopiering av tekst. Vennligst bruk snareveien (Ctrl/Cmd+C).',
+		pasteMsg	: 'Vennligst lim inn i følgende boks med tastaturet (<STRONG>Ctrl/Cmd+V</STRONG>) og trykk <STRONG>OK</STRONG>.',
+		securityMsg	: 'Din nettlesers sikkerhetsinstillinger gir ikke redigeringsverktøyet direkte tilgang til utklippstavlen. Du må derfor lime det inn på nytt i dette vinduet.',
+		pasteArea	: 'Innlimingsområde'
 	},
 
 	pastefromword :
 	{
-		confirmCleanup	: 'The text you want to paste seems to be copied from Word. Do you want to clean it before pasting?', // MISSING
+		confirmCleanup	: 'Teksten du limer inn ser ut til å være kopiert fra Word. Vil du renske den før du limer den inn?',
 		toolbar			: 'Lim inn fra Word',
 		title			: 'Lim inn fra Word',
-		error			: 'It was not possible to clean up the pasted data due to an internal error' // MISSING
+		error			: 'Det var ikke mulig å renske den innlimte teksten på grunn av en intern feil'
 	},
 
 	pasteText :
@@ -528,8 +549,9 @@ CKEDITOR.lang['no'] =
 	{
 		button			: 'Maler',
 		title			: 'Innholdsmaler',
-		insertOption	: 'Erstatt faktisk innold',
-		selectPromptMsg	: 'Velg malen du vil åpne<br>(innholdet du har skrevet blir tapt!):',
+		options : 'Alternativer for mal',
+		insertOption	: 'Erstatt gjeldende innhold',
+		selectPromptMsg	: 'Velg malen du vil åpne i redigeringsverktøyet:',
 		emptyListMsg	: '(Ingen maler definert)'
 	},
 
@@ -538,7 +560,7 @@ CKEDITOR.lang['no'] =
 	stylesCombo :
 	{
 		label		: 'Stil',
-		panelTitle	: 'Formatting Styles', // MISSING
+		panelTitle	: 'Stilformater',
 		panelTitle1	: 'Blokkstiler',
 		panelTitle2	: 'Inlinestiler',
 		panelTitle3	: 'Objektstiler'
@@ -547,37 +569,46 @@ CKEDITOR.lang['no'] =
 	format :
 	{
 		label		: 'Format',
-		panelTitle	: 'Format',
+		panelTitle	: 'Avsnittsformat',
 
 		tag_p		: 'Normal',
 		tag_pre		: 'Formatert',
 		tag_address	: 'Adresse',
-		tag_h1		: 'Tittel 1',
-		tag_h2		: 'Tittel 2',
-		tag_h3		: 'Tittel 3',
-		tag_h4		: 'Tittel 4',
-		tag_h5		: 'Tittel 5',
-		tag_h6		: 'Tittel 6',
+		tag_h1		: 'Overskrift 1',
+		tag_h2		: 'Overskrift 2',
+		tag_h3		: 'Overskrift 3',
+		tag_h4		: 'Overskrift 4',
+		tag_h5		: 'Overskrift 5',
+		tag_h6		: 'Overskrift 6',
 		tag_div		: 'Normal (DIV)'
 	},
 
 	div :
 	{
-		title				: 'Create Div Container', // MISSING
-		toolbar				: 'Create Div Container', // MISSING
-		cssClassInputLabel	: 'Stylesheet Classes', // MISSING
-		styleSelectLabel	: 'Style', // MISSING
-		IdInputLabel		: 'Id', // MISSING
-		languageCodeInputLabel	: ' Language Code', // MISSING
-		inlineStyleInputLabel	: 'Inline Style', // MISSING
-		advisoryTitleInputLabel	: 'Advisory Title', // MISSING
-		langDirLabel		: 'Language Direction', // MISSING
-		langDirLTRLabel		: 'Left to Right (LTR)', // MISSING
-		langDirRTLLabel		: 'Right to Left (RTL)', // MISSING
-		edit				: 'Edit Div', // MISSING
-		remove				: 'Remove Div' // MISSING
+		title				: 'Sett inn Div Container',
+		toolbar				: 'Sett inn Div Container',
+		cssClassInputLabel	: 'Stilark-klasser',
+		styleSelectLabel	: 'Stil',
+		IdInputLabel		: 'Id',
+		languageCodeInputLabel	: ' Språkkode',
+		inlineStyleInputLabel	: 'Inlinestiler',
+		advisoryTitleInputLabel	: 'Tittel',
+		langDirLabel		: 'Språkretning',
+		langDirLTRLabel		: 'Venstre til høyre (VTH)',
+		langDirRTLLabel		: 'Høyre til venstre (HTV)',
+		edit				: 'Rediger Div',
+		remove				: 'Fjern Div'
   	},
 
+	iframe :
+	{
+		title		: 'Egenskaper for IFrame',
+		toolbar		: 'IFrame',
+		noUrl		: 'Vennligst skriv inn URL for iframe',
+		scrolling	: 'Aktiver scrollefelt',
+		border		: 'Viss ramme rundt iframe'
+	},
+
 	font :
 	{
 		label		: 'Skrift',
@@ -596,58 +627,59 @@ CKEDITOR.lang['no'] =
 	{
 		textColorTitle	: 'Tekstfarge',
 		bgColorTitle	: 'Bakgrunnsfarge',
-		panelTitle		: 'Colors', // MISSING
+		panelTitle		: 'Farger',
 		auto			: 'Automatisk',
 		more			: 'Flere farger...'
 	},
 
 	colors :
 	{
-		'000' : 'Black', // MISSING
-		'800000' : 'Maroon', // MISSING
-		'8B4513' : 'Saddle Brown', // MISSING
-		'2F4F4F' : 'Dark Slate Gray', // MISSING
-		'008080' : 'Teal', // MISSING
-		'000080' : 'Navy', // MISSING
-		'4B0082' : 'Indigo', // MISSING
-		'696969' : 'Dim Gray', // MISSING
-		'B22222' : 'Fire Brick', // MISSING
-		'A52A2A' : 'Brown', // MISSING
-		'DAA520' : 'Golden Rod', // MISSING
-		'006400' : 'Dark Green', // MISSING
-		'40E0D0' : 'Turquoise', // MISSING
-		'0000CD' : 'Medium Blue', // MISSING
-		'800080' : 'Purple', // MISSING
-		'808080' : 'Gray', // MISSING
-		'F00' : 'Red', // MISSING
-		'FF8C00' : 'Dark Orange', // MISSING
-		'FFD700' : 'Gold', // MISSING
-		'008000' : 'Green', // MISSING
-		'0FF' : 'Cyan', // MISSING
-		'00F' : 'Blue', // MISSING
-		'EE82EE' : 'Violet', // MISSING
-		'A9A9A9' : 'Dark Gray', // MISSING
-		'FFA07A' : 'Light Salmon', // MISSING
-		'FFA500' : 'Orange', // MISSING
-		'FFFF00' : 'Yellow', // MISSING
-		'00FF00' : 'Lime', // MISSING
-		'AFEEEE' : 'Pale Turquoise', // MISSING
-		'ADD8E6' : 'Light Blue', // MISSING
-		'DDA0DD' : 'Plum', // MISSING
-		'D3D3D3' : 'Light Grey', // MISSING
-		'FFF0F5' : 'Lavender Blush', // MISSING
-		'FAEBD7' : 'Antique White', // MISSING
-		'FFFFE0' : 'Light Yellow', // MISSING
-		'F0FFF0' : 'Honeydew', // MISSING
-		'F0FFFF' : 'Azure', // MISSING
-		'F0F8FF' : 'Alice Blue', // MISSING
-		'E6E6FA' : 'Lavender', // MISSING
-		'FFF' : 'White' // MISSING
+		'000' : 'Svart',
+		'800000' : 'Rødbrun',
+		'8B4513' : 'Salbrun',
+		'2F4F4F' : 'Grønnsvart',
+		'008080' : 'Blågrønn',
+		'000080' : 'Marineblått',
+		'4B0082' : 'Indigo',
+		'696969' : 'Mørk grå',
+		'B22222' : 'Mørkerød',
+		'A52A2A' : 'Brun',
+		'DAA520' : 'Lys brun',
+		'006400' : 'Mørk grønn',
+		'40E0D0' : 'Turkis',
+		'0000CD' : 'Medium blå',
+		'800080' : 'Purpur',
+		'808080' : 'Grå',
+		'F00' : 'Rød',
+		'FF8C00' : 'Mørk oransje',
+		'FFD700' : 'Gull',
+		'008000' : 'Grønn',
+		'0FF' : 'Cyan',
+		'00F' : 'Blå',
+		'EE82EE' : 'Fiolett',
+		'A9A9A9' : 'Svak grå',
+		'FFA07A' : 'Rosa-oransje',
+		'FFA500' : 'Oransje',
+		'FFFF00' : 'Gul',
+		'00FF00' : 'Lime',
+		'AFEEEE' : 'Svak turkis',
+		'ADD8E6' : 'Lys Blå',
+		'DDA0DD' : 'Plomme',
+		'D3D3D3' : 'Lys grå',
+		'FFF0F5' : 'Svak lavendelrosa',
+		'FAEBD7' : 'Antikk-hvit',
+		'FFFFE0' : 'Lys gul',
+		'F0FFF0' : 'Honningmelon',
+		'F0FFFF' : 'Svakt asurblått',
+		'F0F8FF' : 'Svak cyan',
+		'E6E6FA' : 'Lavendel',
+		'FFF' : 'Hvit'
 	},
 
 	scayt :
 	{
 		title			: 'Stavekontroll mens du skriver',
+		opera_title		: 'Ikke støttet av Opera',
 		enable			: 'Slå på SCAYT',
 		disable			: 'Slå av SCAYT',
 		about			: 'Om SCAYT',
@@ -658,10 +690,24 @@ CKEDITOR.lang['no'] =
 		ignore			: 'Ignorer',
 		ignoreAll		: 'Ignorer Alle',
 		addWord			: 'Legg til ord',
-		emptyDic		: 'Ordboknavn skal ikke være tom',
+		emptyDic		: 'Ordboknavn bør ikke være tom.',
+
 		optionsTab		: 'Valg',
+		allCaps			: 'Ikke kontroller ord med kun store bokstaver',
+		ignoreDomainNames : 'Ikke kontroller domenenavn',
+		mixedCase		: 'Ikke kontroller ord med blandet små og store bokstaver',
+		mixedWithDigits	: 'Ikke kontroller ord som inneholder tall',
+
 		languagesTab	: 'Språk',
+
 		dictionariesTab	: 'Ordbøker',
+		dic_field_name	: 'Ordboknavn',
+		dic_create		: 'Opprett',
+		dic_restore		: 'Gjenopprett',
+		dic_delete		: 'Slett',
+		dic_rename		: 'Gi nytt navn',
+		dic_info		: 'Brukerordboken lagres først i en informasjonskapsel på din maskin, men det er en begrensning på hvor mye som kan lagres her. Når ordboken blir for stor til å lagres i en informasjonskapsel, vil vi i stedet lagre ordboken på vår server. For å lagre din personlige ordbok på vår server, burde du velge et navn for ordboken din. Hvis du allerede har lagret en ordbok, vennligst skriv inn ordbokens navn og klikk på Gjenopprett-knappen.',
+
 		aboutTab		: 'Om'
 	},
 
@@ -669,7 +715,9 @@ CKEDITOR.lang['no'] =
 	{
 		title		: 'Om CKEditor',
 		dlgTitle	: 'Om CKEditor',
-		moreInfo	: 'For lisensieringsinformasjon vennligst besøk vårt nettsted:',
+		help	: 'Check $1 for help.', // MISSING
+		userGuide : 'CKEditor User\'s Guide', // MISSING
+		moreInfo	: 'For lisensieringsinformasjon, vennligst besøk vårt nettsted:',
 		copy		: 'Copyright &copy; $1. Alle rettigheter reservert.'
 	},
 
@@ -678,10 +726,11 @@ CKEDITOR.lang['no'] =
 
 	fakeobjects :
 	{
-		anchor	: 'Anker',
-		flash	: 'Flash Animasjon',
-		div		: 'Sideskift',
-		unknown	: 'Ukjent objekt'
+		anchor		: 'Anker',
+		flash		: 'Flash-animasjon',
+		iframe		: 'IFrame',
+		hiddenfield	: 'Skjult felt',
+		unknown		: 'Ukjent objekt'
 	},
 
 	resize : 'Dra for å skalere',
@@ -689,11 +738,73 @@ CKEDITOR.lang['no'] =
 	colordialog :
 	{
 		title		: 'Velg farge',
+		options	:	'Alternativer for farge',
 		highlight	: 'Merk',
 		selected	: 'Valgt',
 		clear		: 'Tøm'
 	},
 
-	toolbarCollapse	: 'Collapse Toolbar', // MISSING
-	toolbarExpand	: 'Expand Toolbar' // MISSING
+	toolbarCollapse	: 'Skjul verktøylinje',
+	toolbarExpand	: 'Vis verktøylinje',
+
+	toolbarGroups :
+	{
+		document : 'Document', // MISSING
+		clipboard : 'Clipboard/Undo', // MISSING
+		editing : 'Editing', // MISSING
+		forms : 'Forms', // MISSING
+		basicstyles : 'Basic Styles', // MISSING
+		paragraph : 'Paragraph', // MISSING
+		links : 'Links', // MISSING
+		insert : 'Insert', // MISSING
+		styles : 'Styles', // MISSING
+		colors : 'Colors', // MISSING
+		tools : 'Tools' // MISSING
+	},
+
+	bidi :
+	{
+		ltr : 'Tekstretning fra venstre til høyre',
+		rtl : 'Tekstretning fra høyre til venstre'
+	},
+
+	docprops :
+	{
+		label : 'Document Properties', // MISSING
+		title : 'Document Properties', // MISSING
+		design : 'Design', // MISSING
+		meta : 'Meta Tags', // MISSING
+		chooseColor : 'Choose', // MISSING
+		other : 'Other...', // MISSING
+		docTitle :	'Page Title', // MISSING
+		charset : 	'Character Set Encoding', // MISSING
+		charsetOther : 'Other Character Set Encoding', // MISSING
+		charsetASCII : 'ASCII', // MISSING
+		charsetCE : 'Central European', // MISSING
+		charsetCT : 'Chinese Traditional (Big5)', // MISSING
+		charsetCR : 'Cyrillic', // MISSING
+		charsetGR : 'Greek', // MISSING
+		charsetJP : 'Japanese', // MISSING
+		charsetKR : 'Korean', // MISSING
+		charsetTR : 'Turkish', // MISSING
+		charsetUN : 'Unicode (UTF-8)', // MISSING
+		charsetWE : 'Western European', // MISSING
+		docType : 'Document Type Heading', // MISSING
+		docTypeOther : 'Other Document Type Heading', // MISSING
+		xhtmlDec : 'Include XHTML Declarations', // MISSING
+		bgColor : 'Background Color', // MISSING
+		bgImage : 'Background Image URL', // MISSING
+		bgFixed : 'Non-scrolling (Fixed) Background', // MISSING
+		txtColor : 'Text Color', // MISSING
+		margin : 'Page Margins', // MISSING
+		marginTop : 'Top', // MISSING
+		marginLeft : 'Left', // MISSING
+		marginRight : 'Right', // MISSING
+		marginBottom : 'Bottom', // MISSING
+		metaKeywords : 'Document Indexing Keywords (comma separated)', // MISSING
+		metaDescription : 'Document Description', // MISSING
+		metaAuthor : 'Author', // MISSING
+		metaCopyright : 'Copyright', // MISSING
+		previewHtml : '<p>This is some <strong>sample text</strong>. You are using <a href="javascript:void(0)">CKEditor</a>.</p>' // MISSING
+	}
 };
