@@ -1,5 +1,5 @@
 ﻿/*
-Copyright (c) 2003-2010, CKSource - Frederico Knabben. All rights reserved.
+Copyright (c) 2003-2011, CKSource - Frederico Knabben. All rights reserved.
 For licensing, see LICENSE.html or http://ckeditor.com/license
 */
 
@@ -16,10 +16,10 @@ For licensing, see LICENSE.html or http://ckeditor.com/license
 		var doc = editor.document,
 			body = doc.getBody();
 
-		var	enabled = false;
+		var enabled = 0;
 		var onExec = function()
 		{
-			enabled = true;
+			enabled = 1;
 		};
 
 		// The following seems to be the only reliable way to detect that
@@ -49,7 +49,7 @@ For licensing, see LICENSE.html or http://ckeditor.com/license
 				try
 				{
 					// Other browsers throw an error if the command is disabled.
-					return editor.document.$.execCommand( type );
+					return editor.document.$.execCommand( type, false, null );
 				}
 				catch( e )
 				{
@@ -61,7 +61,8 @@ For licensing, see LICENSE.html or http://ckeditor.com/license
 	var cutCopyCmd = function( type )
 	{
 		this.type = type;
-		this.canUndo = ( this.type == 'cut' );		// We can't undo copy to clipboard.
+		this.canUndo = this.type == 'cut';		// We can't undo copy to clipboard.
+		this.startDisabled = true;
 	};
 
 	cutCopyCmd.prototype =
@@ -157,22 +158,24 @@ For licensing, see LICENSE.html or http://ckeditor.com/license
 		}
 	};
 
+	function cancel( evt ) { evt.cancel(); }
+
 	// Allow to peek clipboard content by redirecting the
 	// pasting content into a temporary bin and grab the content of it.
 	function getClipboardData( evt, mode, callback )
 	{
 		var doc = this.document;
 
-		// Avoid recursions on 'paste' event for IE.
-		if ( CKEDITOR.env.ie && doc.getById( 'cke_pastebin' ) )
+		// Avoid recursions on 'paste' event or consequent paste too fast. (#5730)
+		if ( doc.getById( 'cke_pastebin' ) )
 			return;
 
 		// If the browser supports it, get the data directly
-		if (mode == 'text' && evt.data && evt.data.$.clipboardData)
+		if ( mode == 'text' && evt.data && evt.data.$.clipboardData )
 		{
 			// evt.data.$.clipboardData.types contains all the flavours in Mac's Safari, but not on windows.
 			var plain = evt.data.$.clipboardData.getData( 'text/plain' );
-			if (plain)
+			if ( plain )
 			{
 				evt.data.preventDefault();
 				callback( plain );
@@ -207,22 +210,11 @@ For licensing, see LICENSE.html or http://ckeditor.com/license
 
 		var bms = sel.createBookmarks();
 
+		this.on( 'selectionChange', cancel, null, null, 0 );
+
 		// Turn off design mode temporarily before give focus to the paste bin.
 		if ( mode == 'text' )
-		{
-			if ( CKEDITOR.env.ie )
-			{
-				var ieRange = doc.getBody().$.createTextRange();
-				ieRange.moveToElementText( pastebin.$ );
-				ieRange.execCommand( 'Paste' );
-				evt.data.preventDefault();
-			}
-			else
-			{
-				doc.$.designMode = 'off';
-				pastebin.$.focus();
-			}
-		}
+			pastebin.$.focus();
 		else
 		{
 			range.setStartAt( pastebin, CKEDITOR.POSITION_AFTER_START );
@@ -230,11 +222,13 @@ For licensing, see LICENSE.html or http://ckeditor.com/license
 			range.select( true );
 		}
 
+		var editor  = this;
 		// Wait a while and grab the pasted contents
 		window.setTimeout( function()
 		{
-			mode == 'text' && !CKEDITOR.env.ie && ( doc.$.designMode = 'on' );
+			mode == 'text' && CKEDITOR.env.gecko && editor.focusGrabber.focus();
 			pastebin.remove();
+			editor.removeListener( 'selectionChange', cancel );
 
 			// Grab the HTML contents.
 			// We need to look for a apple style wrapper on webkit it also adds
@@ -254,7 +248,7 @@ For licensing, see LICENSE.html or http://ckeditor.com/license
 	// Cutting off control type element in IE standards breaks the selection entirely. (#4881)
 	function fixCut( editor )
 	{
-		if ( !CKEDITOR.env.ie || editor.document.$.compatMode == 'BackCompat' )
+		if ( !CKEDITOR.env.ie || CKEDITOR.env.quirks )
 			return;
 
 		var sel = editor.getSelection();
@@ -281,6 +275,34 @@ For licensing, see LICENSE.html or http://ckeditor.com/license
 		}
 	}
 
+	var depressBeforeEvent;
+	function stateFromNamedCommand( command, editor )
+	{
+		// IE Bug: queryCommandEnabled('paste') fires also 'beforepaste(copy/cut)',
+		// guard to distinguish from the ordinary sources( either
+		// keyboard paste or execCommand ) (#4874).
+		CKEDITOR.env.ie && ( depressBeforeEvent = 1 );
+
+		var retval = CKEDITOR.TRISTATE_OFF;
+		try { retval = editor.document.$.queryCommandEnabled( command ) ? CKEDITOR.TRISTATE_OFF : CKEDITOR.TRISTATE_DISABLED; }catch( er ){}
+
+		depressBeforeEvent = 0;
+		return retval;
+	}
+
+	var inReadOnly;
+	function setToolbarStates()
+	{
+		if ( this.mode != 'wysiwyg' )
+			return;
+
+		this.getCommand( 'cut' ).setState( inReadOnly ? CKEDITOR.TRISTATE_DISABLED : stateFromNamedCommand( 'Cut', this ) );
+		this.getCommand( 'copy' ).setState( stateFromNamedCommand( 'Copy', this ) );
+		var pasteState = inReadOnly ? CKEDITOR.TRISTATE_DISABLED :
+						CKEDITOR.env.webkit ? CKEDITOR.TRISTATE_OFF : stateFromNamedCommand( 'Paste', this );
+		this.fire( 'pasteState', pasteState );
+	}
+
 	// Register the plugin.
 	CKEDITOR.plugins.add( 'clipboard',
 		{
@@ -297,6 +319,8 @@ For licensing, see LICENSE.html or http://ckeditor.com/license
 						else if ( data[ 'text' ] )
 							editor.insertText( data[ 'text' ] );
 
+						setTimeout( function () { editor.fire( 'afterPaste' ); }, 0 );
+
 					}, null, null, 1000 );
 
 				editor.on( 'pasteDialog', function( evt )
@@ -308,6 +332,11 @@ For licensing, see LICENSE.html or http://ckeditor.com/license
 						}, 0 );
 					});
 
+				editor.on( 'pasteState', function( evt )
+					{
+						editor.getCommand( 'paste' ).setState( evt.data );
+					});
+
 				function addButtonCommand( buttonName, commandName, command, ctxMenuOrder )
 				{
 					var lang = editor.lang[ commandName ];
@@ -340,59 +369,58 @@ For licensing, see LICENSE.html or http://ckeditor.com/license
 
 				editor.on( 'key', onKey, editor );
 
-				var mode = editor.config.forcePasteAsPlainText ? 'text' : 'html';
-
 				// We'll be catching all pasted content in one line, regardless of whether the
 				// it's introduced by a document command execution (e.g. toolbar buttons) or
 				// user paste behaviors. (e.g. Ctrl-V)
 				editor.on( 'contentDom', function()
 				{
 					var body = editor.document.getBody();
-					body.on( ( (mode == 'text' && CKEDITOR.env.ie) || CKEDITOR.env.webkit ) ? 'paste' : 'beforepaste',
-						function( evt )
+					body.on( CKEDITOR.env.webkit ? 'paste' : 'beforepaste', function( evt )
 						{
 							if ( depressBeforeEvent )
 								return;
 
-							getClipboardData.call( editor, evt, mode, function ( data )
+							// Fire 'beforePaste' event so clipboard flavor get customized
+							// by other plugins.
+							var eventData =  { mode : 'html' };
+							editor.fire( 'beforePaste', eventData );
+
+							getClipboardData.call( editor, evt, eventData.mode, function ( data )
 							{
 								// The very last guard to make sure the
 								// paste has successfully happened.
-								if ( !data )
+								if ( !( data = CKEDITOR.tools.trim( data.replace( /<span[^>]+data-cke-bookmark[^<]*?<\/span>/ig,'' ) ) ) )
 									return;
 
 								var dataTransfer = {};
-								dataTransfer[ mode ] = data;
+								dataTransfer[ eventData.mode ] = data;
 								editor.fire( 'paste', dataTransfer );
 							} );
 						});
 
 					body.on( 'beforecut', function() { !depressBeforeEvent && fixCut( editor ); } );
+
+					body.on( 'mouseup', function(){ setTimeout( function(){ setToolbarStates.call( editor ); }, 0 ); }, editor );
+					body.on( 'keyup', setToolbarStates, editor );
+				});
+
+				// For improved performance, we're checking the readOnly state on selectionChange instead of hooking a key event for that.
+				editor.on( 'selectionChange', function( evt )
+				{
+					inReadOnly = evt.data.selection.getRanges()[ 0 ].checkReadOnly();
+					setToolbarStates.call( editor );
 				});
 
 				// If the "contextmenu" plugin is loaded, register the listeners.
 				if ( editor.contextMenu )
 				{
-					var depressBeforeEvent;
-					function stateFromNamedCommand( command )
-					{
-						// IE Bug: queryCommandEnabled('paste') fires also 'beforepaste(copy/cut)',
-						// guard to distinguish from the ordinary sources( either
-						// keyboard paste or execCommand ) (#4874).
-						CKEDITOR.env.ie && ( depressBeforeEvent = 1 );
-
-						var retval = editor.document.$.queryCommandEnabled( command ) ? CKEDITOR.TRISTATE_OFF : CKEDITOR.TRISTATE_DISABLED;
-						depressBeforeEvent = 0;
-						return retval;
-					}
-
 					editor.contextMenu.addListener( function( element, selection )
 						{
-							var readOnly = selection.getCommonAncestor().isReadOnly();
+							var readOnly = selection.getRanges()[ 0 ].checkReadOnly();
 							return {
-								cut : !readOnly && stateFromNamedCommand( 'Cut' ),
-								copy : stateFromNamedCommand( 'Copy' ),
-								paste : !readOnly && ( CKEDITOR.env.webkit ? CKEDITOR.TRISTATE_OFF : stateFromNamedCommand( 'Paste' ) )
+								cut : !readOnly && stateFromNamedCommand( 'Cut', editor ),
+								copy : stateFromNamedCommand( 'Copy', editor ),
+								paste : !readOnly && ( CKEDITOR.env.webkit ? CKEDITOR.TRISTATE_OFF : stateFromNamedCommand( 'Paste', editor ) )
 							};
 						});
 				}
@@ -410,3 +438,9 @@ For licensing, see LICENSE.html or http://ckeditor.com/license
  * @param {String} [data.html] The HTML data to be pasted. If not available, e.data.text will be defined.
  * @param {String} [data.text] The plain text data to be pasted, available when plain text operations are to used. If not available, e.data.html will be defined.
  */
+
+/**
+ * Internal event to open the Paste dialog
+ * @name CKEDITOR.editor#pasteDialog
+ * @event
+ */
