@@ -1,4 +1,7 @@
-// $Id: ckeditor.utils.js,v 1.1.2.14 2010/07/05 14:11:52 wwalc Exp $
+/*
+Copyright (c) 2003-2011, CKSource - Frederico Knabben. All rights reserved.
+For licensing, see LICENSE.html or http://ckeditor.com/license
+*/
 Drupal.ckeditor = (typeof(CKEDITOR) != 'undefined');
 
 // this object will store teaser information
@@ -17,6 +20,7 @@ Drupal.ckeditorToggle = function(textarea_id, TextTextarea, TextRTE, xss_check){
     $('#switch_' + textarea_id).text(TextRTE);
   }
   else {
+    $("#" + textarea_id).val(Drupal.ckeditorLinebreakConvert(textarea_id, $("#" + textarea_id).val()));
     Drupal.ckeditorOn(textarea_id);
     $('#switch_' + textarea_id).text(TextTextarea);
   }
@@ -104,6 +108,7 @@ Drupal.ckeditorOn = function(textarea_id) {
     focus : function(ev)
     {
       Drupal.ckeditorInstance = ev.editor;
+      Drupal.ckeditorActiveId = ev.editor.name;
     }
   };
 
@@ -192,7 +197,11 @@ Drupal.ckeditorCompareVersion = function (version){
     if (ckver[x]<version[x]) {
       return false;
     }
+    else if (ckver[x]>version[x]) {
+      return true;
+    }
   }
+
   return true;
 };
 
@@ -261,6 +270,28 @@ Drupal.ckeditorInsertHtml = function(html) {
   }
 };
 
+/**
+ * Converts \n to <br />
+ * It in no way tries to compete with Line break converter filter
+ */
+Drupal.ckeditorEnterModeConvert = function(enterMode){
+  if (enterMode == 1)
+    return {startTag: '<p>', endTag: '</p>'};
+  if (enterMode == 2)
+    return {startTag: '', endTag: '<br/>'};
+  if (enterMode == 3)
+    return {startTag: '<div>', endTag: '</div>'};
+  return {startTag: '', endTag: ''}
+}
+
+Drupal.ckeditorLinebreakConvert = function(textarea_id, text) {
+  var enterMode = Drupal.ckeditorEnterModeConvert(Drupal.settings.ckeditor.settings[textarea_id].enterMode);
+  if (!text.match(/<(div|p|br).*\/?>/i) && text) {
+    text = enterMode.startTag +  text.replace(/\r\n|\n\r/g, '\n').replace(/\n\n/g, enterMode.endTag+enterMode.startTag).replace(/\n/g, '<br />')  + enterMode.endTag;
+  }
+  return text;
+}
+
 /**
  * Ajax support [#741572]
  */
@@ -339,5 +370,12 @@ Drupal.behaviors.ckeditor = function (context) {
     if ((typeof(Drupal.settings.ckeditor.autostart) != 'undefined') && (typeof(Drupal.settings.ckeditor.autostart[ta_id]) != 'undefined')) {
       Drupal.ckeditorOn(ta_id);
     }
+    else {
+      $(this).parents('form').bind('submit', function() {
+        $(this).find('textarea').each(function() {
+          $(this).val(Drupal.ckeditorLinebreakConvert(ta_id, $(this).val()));
+        });
+      });
+    }
   });
 };
\ No newline at end of file
