@@ -1,5 +1,5 @@
 /*
-Copyright (c) 2003-2009, CKSource - Frederico Knabben. All rights reserved.
+Copyright (c) 2003-2011, CKSource - Frederico Knabben. All rights reserved.
 For licensing, see LICENSE.html or http://ckeditor.com/license
 */
 
@@ -39,7 +39,7 @@ CKEDITOR.plugins.add( 'drupalbreaks',
 			editor.ui.addButton( 'DrupalBreak',
 				{
 					label : Drupal.t('Insert Teaser Break'),
-					icon : this.path + 'images/drupalbreak.gif',
+					icon : this.path + 'images/drupalbreak.png',
 					command : 'drupalbreak'
 				});
 
@@ -47,7 +47,7 @@ CKEDITOR.plugins.add( 'drupalbreaks',
 				editor.ui.addButton( 'DrupalPageBreak',
 						{
 							label : Drupal.t( 'Insert Page Break' ),
-							icon : this.path + 'images/drupalpagebreak.gif',
+							icon : this.path + 'images/drupalpagebreak.png',
 							command : 'drupalpagebreak'
 						});
 			}
